@@ -23,6 +23,8 @@
  *
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include "gpa-widget.h"
 
@@ -50,7 +52,7 @@ gpa_widget_get_type (void)
 			sizeof (GPAWidget),
 			0,
 			(GInstanceInitFunc) gpa_widget_init,
-			NULL,
+			NULL
 		};
 		type = g_type_register_static (GTK_TYPE_BIN, "GPAWidget", &info, 0);
 	}
